.. _recipe_asr.dos:

asr.dos
=======


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.dos`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.dos.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.dos

or as a python module

.. code-block:: console

   $ python -m asr.dos

Detailed description
--------------------
Density of states.

Steps
-----


asr.dos
^^^^^^^
.. autofunction:: asr.dos.main
   